# HAHAHA Utils

HAHAHA Python3工具库

## 打包
```shell script
    # pip install twine
    
    # python setup.py build
    
    # python setup.py sdist
    
    python -m build
    
    # python3 -m twine upload --repository pypi dist/*

    # vim ~/.pypirc

    twine upload dist/*
```